{# templates/device.j2 #}
<div style="border-bottom: 1px solid #ddd; padding: 10px 0; margin: 15px 0;"><h3 style="margin: 0; color: #1e3a8a; font-size: 18px;"><i class="fas fa-info-circle" style="margin-right: 8px;"></i> Hostname {{ name }} </h3></div>
<div style="border-bottom: 1px solid #ddd; padding: 10px 0; margin: 15px 0;"><h3 style="margin: 0; color: #1e3a8a; font-size: 18px;"><i class="fas fa-cog" style="margin-right: 8px;"></i> Información del dispositivo </h3></div>
<p>
    Hostname:         {{ name }} <br />
    IOS Version:      {{ version }} <br />
    Model:            {{ model }} <br />
    Serial Number:    {{ snumb }} <br />
    Tipo:             {{ type }} <br />
    <strong>Hardening Factor: {{ score_percent }} %</strong> <br /><br />
    ===============================================
</p>