{# templates/snmp.j2 #}
<div style="border-bottom: 1px solid #ddd; padding: 10px 0; margin: 15px 0;"><h3 style="margin: 0; color: #1e3a8a; font-size: 18px;"><i class="fas fa-cog" style="margin-right: 8px;"></i> SNMP </h3></div>
<div class="annex-grid">
{% if check and not check2 %}
        <span class="status-icon status-pass">✓</span>
        <div class="cell">No se está utilizando SNMP.</div>
{% elif check and check2 %}
        <span class="status-icon status-pass">✓</span>
        <div class="cell">
            Se está utilizando SNMP con ACLs en todas las comunidades:
            <ul style="margin: 5px 0; padding-left: 20px;">
            {% for result in value2 %}
                <li>{{ result }}</li>
            {% endfor %}
            </ul>
        </div>
{% elif not check and not check2 %}
        <span class="status-icon status-fail">⚠</span>
        <div class="cell">
            Se está utilizando SNMP sin ACLs en todas las comunidades:
            <ul style="margin: 5px 0; padding-left: 20px;">
            {% for result in value1 %}
                <li>{{ result }}</li>
            {% endfor %}
            </ul>
        </div>
{% else %}
        <span class="status-icon status-pass">✓</span>
        <div class="cell">
            Se está utilizando SNMP con ACLs en las siguientes comunidades:
            <ul style="margin: 5px 0; padding-left: 20px;">
            {% for result in value2 %}
                <li>{{ result }}</li>
            {% endfor %}
            </ul>
        </div>
        <span class="status-icon status-fail">⚠</span>
        <div class="cell">
            Se está utilizando SNMP sin ACLs en las comunidades:
            <ul style="margin: 5px 0; padding-left: 20px;">
            {% for result in value1 %}
                <li>{{ result }}</li>
            {% endfor %}
            </ul>
        </div>
{% endif %}
{% if check3 %}
        <span class="status-icon status-fail">⚠</span>
        <div class="cell">Se está utilizando alguna de las siguientes comunidades SNMP: public, PUBLIC, private, PRIVATE. <br />
        Se recomienda encarecidamente cambiar los nombres lo antes posible.</div>
{% endif %}
</div>