{# templates/not.j2 #}
<div style="border-bottom: 1px solid #ddd; padding: 10px 0; margin: 15px 0;"><h3 style="margin: 0; color: #1e3a8a; font-size: 18px;"><i class="fas fa-cog" style="margin-right: 8px;"></i> Verificación del servicio {{ test }} </h3></div>
<div class="annex-grid">
{% if check %}
        <span class="status-icon status-pass">✓</span>
        <div class="cell">{{ test }} esta deshabilitado.</div>
{% else %}
        <span class="status-icon status-fail">⚠</span>
        <div class="cell">{{ test }} está habilitado.</div>
{% endif %}
</div>