{# templates/logging_source.j2 #}
<div class="annex-grid">
{% if check %}
        <span class="status-icon status-pass">✓</span>
        <div class="cell">{{ test }} está configurado con la interfaz {{ value1 }}.</div>
{% else %}
        <span class="status-icon status-fail">⚠</span>
        <div class="cell">Es recomendable configurar {{ test }}.</div>
{% endif %}
</div>