{# templates/device2.j2 #}
<div style="border-bottom: 1px solid #ddd; padding: 10px 0; margin: 15px 0;"><h3 style="margin: 0; color: #1e3a8a; font-size: 18px;"><i class="fas fa-info-circle" style="margin-right: 8px;"></i> Hostname {{ name }} </h3></div>
<div style="border-bottom: 1px solid #ddd; padding: 10px 0; margin: 15px 0;"><h3 style="margin: 0; color: #1e3a8a; font-size: 18px;"><i class="fas fa-cog" style="margin-right: 8px;"></i> Información del dispositivo </h3></div>
<div class="top-container">
    <div class="frame">
        <div class="left-frame">
            <p><strong>
                Hostname:         {{ name }} <br />
                IOS Version:      {{ version }} <br />
                Model:            {{ model }} <br />
                Serial Number:    {{ snumb }} <br />
                Tipo:             {{ type }} <br />
            </strong></p>
        </div>
        <div class="right-frame">
            <p><strong>
                Hardening Factor: {{ score_percent }} % <br />
                Score Operativo:  {{ operativa_percent }} % <br />
                Score Control:    {{ control_percent }} % <br />
                Score Acceso:     {{ acceso_percent }} % <br />
                Score Monitoreo:  {{ monitoreo_percent }} % <br />
            </strong></p>
        </div>
    </div>
</div>
<div class="bottom-container">
    <div class="left-column">
        <img src="./{{ name + '_radar_chart.jpg' }}" alt="Image" width="100%">
    </div>
    <div class="right-column">
        <img src="./{{ name + '.jpg' }}" alt="Image" width="100%">
    </div>
</div>
<br />