"""
HVT6 Version Information

Single source of truth for version metadata.
"""

__version__ = "6.5.2"
__version_info__ = tuple(int(x) for x in __version__.split('.'))

# Package metadata
__title__ = "hvt6"
__description__ = "Hardening Verification Tool for Cisco IOS/IOS-XE/NX-OS devices"
__author__ = "Nicolas Padin"
__author_email__ = "npadin@example.com"
__license__ = "GPL-3.0-or-later"
__copyright__ = "Copyright 2025 HVT6 Team"
__url__ = "https://github.com/npadin/ios-xe_hardening"

# Release information
__status__ = "Production/Stable"
__release_date__ = "2025-11-14"
